@@ -4,7 +4,7 @@ from interactions.ext import Base, Version, VersionAuthor
 from .persistence import Persistence
 
 version = Version(
-    version="2.0.0",
+    version="2.1.0",
     author=VersionAuthor(
         name="Dworv",
         email="dwarvyt@gmail.com",
@@ -14,7 +14,7 @@ version = Version(
 base = Base(
     name="Persistence",
     version=version,
-    link=f"https://github.com/dworv/interactions-persistence",
+    link="https://github.com/dworv/interactions-persistence",
     description="An extension to add simple custom_id encoding to interactions.py.",
     packages="interactions.ext.persistence",
 )
